@@ -151,7 +151,7 @@ def exists_ftp(file_path, ftp):
     '''
     dir_exists = False
     try:
-        if ftp.exists(file_path):
+        if ftp.path.exists(file_path):
             dir_exists = True
     except ftputil.error.PermanentError as error:
         print(f"error: {str(error)}")
@@ -842,14 +842,15 @@ def delete(file_path, ftp=None):
     success = False
     if ftp is not None:
         success = delete_ftp(file_path, ftp)
-    try:
-        shutil.rmtree(file_path)
-        success = True
-    except OSError as error:
-        logger.warning("Failed to delete directory: %s", file_path)
-        logger.warning("Error: %s : %s", file_path, error.strerror)
-        success = False
-        # print("Error: %s : %s" % (file_path, error.strerror))
+    else:
+        try:
+            shutil.rmtree(file_path)
+            success = True
+        except OSError as error:
+            logger.warning("Failed to delete local directory: %s", file_path)
+            logger.warning("Error: %s : %s", file_path, error.strerror)
+            success = False
+            # print("Error: %s : %s" % (file_path, error.strerror))
     return success
 
 
@@ -881,14 +882,15 @@ def delete_ftp(file_path, ftp):
     '''
     success = False
     if exists_ftp(file_path, ftp):
+        print(f"{file_path} exists.")
         try:
             ftp.rmtree(file_path)
-            if exists_ftp(file_path, ftp) is False:
-                success = True
+            success = True
         except FTPOSError as error:
-            logger.warning("Failed to delete directory: %s", file_path)
+            logger.warning("Failed to delete FTP directory: %s", file_path)
             logger.warning("Error: %s : %s", file_path, error.strerror)
-            success = False
+    else:
+        success = True
     return success
 
 
