@@ -332,12 +332,12 @@ def _parse_copy_data_from_obj(file_obj):
             print("Invalid list/tuple provided for copy file. Must be [source_file_path, destination_file_path]")
     if isinstance(file_obj, (dict)):
         for syn in utils.resources.SRC_PATH_SYNONYMS:
-            synvar = obj.gen_variations(syn)
+            synvar = strUtils.gen.variations(syn)
             for synonym_variant in synvar:
                 if synonym_variant in file_obj:
                     data['src_path'] = file_obj[synonym_variant]
         for syn in utils.resources.DEST_PATH_SYNONYMS:
-            synvar = obj.gen_variations(syn)
+            synvar = strUtils.gen.variations(syn)
             for synonym_variant in synvar:
                 if synonym_variant in file_obj:
                     data['dst_path'] = file_obj[synonym_variant]
